Crate atsamrh71f20c

Crate atsamrh71f20c 

Peripheral access API for ATSAMS70Q21 microcontrollers (generated using svd2rust v0.33.5 ( ))

You can find an overview of the generated API [here] .

API features to be included in the [next] svd2rust release can be generated by cloning the svd2rust [repository] , checking out the above commit, and running cargo doc --open.

[here] : https://docs.rs/svd2rust/0.33.5/svd2rust/#peripheral-api [next] : https://github.com/rust-embedded/svd2rust/blob/master/CHANGELOG.md#unreleased [repository] : https://github.com/rust-embedded/svd2rust

Re-exports

pub use self::flexcom0 as flexcom1;
pub use self::flexcom0 as flexcom2;
pub use self::flexcom0 as flexcom3;
pub use self::flexcom0 as flexcom4;
pub use self::flexcom0 as flexcom5;
pub use self::flexcom0 as flexcom6;
pub use self::flexcom0 as flexcom7;
pub use self::flexcom0 as flexcom8;
pub use self::flexcom0 as flexcom9;
pub use self::mcan0 as mcan1;
pub use self::pwm0 as pwm1;
pub use self::tc0 as tc1;
pub use self::tc0 as tc2;
pub use self::tc0 as tc3;

Modules

chipid
Chip Identifier
core_debug
Core Debug Register
etm
Embedded Trace Macrocell
flexcom0
Flexible Serial Communication
flexramecc
FLEXRAMECC
generic
Common register and bit access and modify traits
gmac
Gigabit Ethernet MAC
hefc
Harden Embedded Flash Controller
hemc
HEMC
hsdramc
Hardened SDRAM Controller
hsmc
Harden Static Memory Controller
icm
Integrity Check Monitor
ip1553
IP 1553
lockbit
LOCKBIT
matrix0
AHB Bus Matrix
mcan0
Controller Area Network
nmic
Non-maskable Interrupt Controller
pio
Parallel Input/Output Controller
pmc
Power Management Controller
pwm0
Pulse Width Modulation Controller
qspi
Quad Serial Peripheral Interface
rstc
Reset Controller
rswdt
Reinforced Safety Watchdog Timer
rtc
Real-time Clock
rtt
Real-time Timer
scn_scb
System control not in SCB
sfr
Special Function Registers
sha
Secure Hash Algorithm
spw
SpW
supc
Supply Controller
sys_tick
System timer
tc0
Timer Counter
tcmecc
HECC
trng
True Random Number Generator
wdt
Watchdog Timer
xdmac
Extensible DMA Controller

Structs

CBP
Cache and branch predictor maintenance operations
CHIPID
Chip Identifier
CORE_DEBUG
Core Debug Register
CPUID
CPUID
CorePeripherals
Core peripherals
DCB
Debug Control Block
DWT
Data Watchpoint and Trace unit
ETM
Embedded Trace Macrocell
FLEXCOM0
Flexible Serial Communication
FLEXCOM1
Flexible Serial Communication
FLEXCOM2
Flexible Serial Communication
FLEXCOM3
Flexible Serial Communication
FLEXCOM4
Flexible Serial Communication
FLEXCOM5
Flexible Serial Communication
FLEXCOM6
Flexible Serial Communication
FLEXCOM7
Flexible Serial Communication
FLEXCOM8
Flexible Serial Communication
FLEXCOM9
Flexible Serial Communication
FLEXRAMECC
FLEXRAMECC
FPB
Flash Patch and Breakpoint unit
FPU
Floating Point Unit
GMAC
Gigabit Ethernet MAC
HEFC
Harden Embedded Flash Controller
HEMC
HEMC
HSDRAMC
Hardened SDRAM Controller
HSMC
Harden Static Memory Controller
ICM
Integrity Check Monitor
IP1553
IP 1553
ITM
Instrumentation Trace Macrocell
LOCKBIT
LOCKBIT
MATRIX0
AHB Bus Matrix
MCAN0
Controller Area Network
MCAN1
Controller Area Network
MPU
Memory Protection Unit
NMIC
Non-maskable Interrupt Controller
NVIC
Nested Vector Interrupt Controller
PIO
Parallel Input/Output Controller
PMC
Power Management Controller
PWM0
Pulse Width Modulation Controller
PWM1
Pulse Width Modulation Controller
Peripherals
All the peripherals.
QSPI
Quad Serial Peripheral Interface
RSTC
Reset Controller
RSWDT
Reinforced Safety Watchdog Timer
RTC
Real-time Clock
RTT
Real-time Timer
SCB
System Control Block
SCN_SCB
System control not in SCB
SFR
Special Function Registers
SHA
Secure Hash Algorithm
SPW
SpW
SUPC
Supply Controller
SYST
SysTick: System Timer
SYS_TICK
System timer
TC0
Timer Counter
TC1
Timer Counter
TC2
Timer Counter
TC3
Timer Counter
TCMECC
HECC
TPIU
Trace Port Interface Unit
TRNG
True Random Number Generator
WDT
Watchdog Timer
XDMAC
Extensible DMA Controller

Enums

Interrupt
Enumeration of all the interrupts.

Constants

NVIC_PRIO_BITS
Number available in the NVIC for configuring priority